Enum fleetspeak::WriteError [−][src]
pub enum WriteError {
Output(Error),
Encode(EncodeError),
}Expand description
An error type for failures that occured when sending a message.
Variants
Output(Error)An I/O error occurred when writing to the output stream.
Encode(EncodeError)An error occurred when encoding the proto message to bytes.